@@ -32,6 +32,8 @@ class Director:
         self._tick = 0
         self.running = False
         self.paused = False
+        self.debug_mode = False
+        self.debug_window = None
 
         self._windows: List[Window] = []
 
@@ -176,6 +178,14 @@ class Director:
         # Empty all events!
         pygame.event.get()
 
+    def debug(self, initial_game_state):
+        self.debug_mode = True
+        self.start(initial_game_state)
+
+    def stop_debug_mode(self):
+        self.debug_mode = False
+        self.debug_window = None
+
     def start(self, initial_game_state):
         """
         Starts Pygame main game loop. Checks for events and DirtySprite updates. Handles animations.
@@ -202,6 +212,10 @@ class Director:
         for object in self._all_sprites:
             if object:
                 object._reactivate()
+        # Set up debug window
+        if self.debug_mode:
+            from designer.tk.debug import DebugWindow
+            self.debug_window = DebugWindow(self)
         # Start running the game!
         self.running = True
         try:
