@@ -241,7 +241,7 @@ class Window:
             self._pending = []
 
     def _unregister_object_events(self, object):
-        for name, handlers in self._handlers.items():
+        for name, handlers in list(self._handlers.items()):
             self._handlers[name] = [h for h in handlers
                                     if not hasattr(h[0], '__self__') or h[0].__self__ is not object]
             if not self._handlers[name]:
@@ -532,6 +532,7 @@ class Window:
                     clear_next.append(r)
                 elif screen_rect.colliderect(blit_rect):
                     # Todo: See if this is ever called. Shouldn't be.
+                    # Note: I believe it's called when an object is bigger than the screen
                     x = blit.rect.clip(screen_rect)
                     y = x.move(-blit_rect.left, -blit_rect.top)
                     b = blit.surface.subsurface(y)
